@@ -26,6 +26,9 @@ class ShipmentOut:
 
     tracking_number = fields.Char('Tracking Number', states=STATES)
 
+    carrier_logs = fields.One2Many(
+        'carrier.log', 'shipment_out', 'Carrier Logs', readonly=True
+    )
     package_weight = fields.Function(
         fields.Numeric("Package weight", digits=(16,  2)),
         'get_package_weight'
@@ -36,6 +39,13 @@ class ShipmentOut:
         'get_weight_uom'
     )
 
+    computed_weight = fields.Function(
+        fields.Numeric("Computed Weight", digits=(16,  2)),
+        'get_computed_weight'
+    )
+
+    override_weight = fields.Numeric("Override Weight", digits=(16,  2))
+
     def get_weight_uom(self, name):
         """
         Returns weight uom for the package
@@ -54,6 +64,13 @@ class ShipmentOut:
         return UOM.search([('symbol', '=', 'lb')])[0]
 
     def get_package_weight(self, name):
+        """
+        Returns package weight if weight is not overriden
+        otherwise returns overriden weight
+        """
+        return self.override_weight or self.get_computed_weight()
+
+    def get_computed_weight(self, name=None):
         """
         Returns sum of weight associated with each move line
         """
@@ -65,6 +82,23 @@ class ShipmentOut:
             )
         )
 
+    def add_carrier_log(self, log_data, carrier):
+        """
+        Save log for shipment out
+        """
+        CarrierLog = Pool().get('carrier.log')
+        Config = Pool().get('carrier.configuration')
+
+        if not Config(1).save_carrier_logs:
+            return
+
+        log, = CarrierLog.create([{
+            'shipment_out': self.id,
+            'carrier': carrier,
+            'log': log_data,
+        }])
+        return log
+
 
 class StockMove:
     "Stock move"
